@@ -59,6 +59,7 @@ func main() {
 		autoTossNoExec = flag.Bool("autotoss-noexec", false, "Do not process \"exec\" packets during tossing")
 		autoTossNoTrns = flag.Bool("autotoss-notrns", false, "Do not process \"trns\" packets during tossing")
 		autoTossNoArea = flag.Bool("autotoss-noarea", false, "Do not process \"area\" packets during tossing")
+		autoTossNoACK  = flag.Bool("autotoss-noack", false, "Do not process \"ack\" packets during tossing")
 	)
 	log.SetFlags(log.Lshortfile)
 	flag.Usage = usage
@@ -219,6 +220,7 @@ func main() {
 								call.AutoTossNoExec || *autoTossNoExec,
 								call.AutoTossNoTrns || *autoTossNoTrns,
 								call.AutoTossNoArea || *autoTossNoArea,
+								call.AutoTossNoACK || *autoTossNoACK,
 							)
 						}
 
