@@ -113,14 +113,14 @@ func TestTossExec(t *testing.T) {
 				continue
 			}
 			ctx.Toss(ctx.Self.Id, TRx, DefaultNiceExec-1,
-				false, false, false, false, false, false, false)
+				false, false, false, false, false, false, false, false)
 			if len(dirFiles(rxPath)) == 0 {
 				return false
 			}
 			ctx.Neigh[*nodeOur.Id].Exec = make(map[string][]string)
 			ctx.Neigh[*nodeOur.Id].Exec[handle] = []string{"/bin/sh", "-c", "false"}
 			ctx.Toss(ctx.Self.Id, TRx, DefaultNiceExec,
-				false, false, false, false, false, false, false)
+				false, false, false, false, false, false, false, false)
 			if len(dirFiles(rxPath)) == 0 {
 				return false
 			}
@@ -133,7 +133,7 @@ func TestTossExec(t *testing.T) {
 				),
 			}
 			ctx.Toss(ctx.Self.Id, TRx, DefaultNiceExec,
-				false, false, false, false, false, false, false)
+				false, false, false, false, false, false, false, false)
 			if len(dirFiles(rxPath)) != 0 {
 				return false
 			}
@@ -220,13 +220,13 @@ func TestTossFile(t *testing.T) {
 		rxPath := filepath.Join(spool, ctx.Self.Id.String(), string(TRx))
 		os.Rename(filepath.Join(spool, ctx.Self.Id.String(), string(TTx)), rxPath)
 		ctx.Toss(ctx.Self.Id, TRx, DefaultNiceFile,
-			false, false, false, false, false, false, false)
+			false, false, false, false, false, false, false, false)
 		if len(dirFiles(rxPath)) == 0 {
 			return false
 		}
 		ctx.Neigh[*nodeOur.Id].Incoming = &incomingPath
 		if ctx.Toss(ctx.Self.Id, TRx, DefaultNiceFile,
-			false, false, false, false, false, false, false) {
+			false, false, false, false, false, false, false, false) {
 			return false
 		}
 		if len(dirFiles(rxPath)) != 0 {
@@ -303,7 +303,7 @@ func TestTossFileSameName(t *testing.T) {
 		os.Rename(filepath.Join(spool, ctx.Self.Id.String(), string(TTx)), rxPath)
 		ctx.Neigh[*nodeOur.Id].Incoming = &incomingPath
 		ctx.Toss(ctx.Self.Id, TRx, DefaultNiceFile,
-			false, false, false, false, false, false, false)
+			false, false, false, false, false, false, false, false)
 		expected := make(map[string]struct{})
 		expected["samefile"] = struct{}{}
 		for i := 0; i < files-1; i++ {
@@ -379,13 +379,13 @@ func TestTossFreq(t *testing.T) {
 		os.Rename(txPath, rxPath)
 		os.MkdirAll(txPath, os.FileMode(0700))
 		ctx.Toss(ctx.Self.Id, TRx, DefaultNiceFreq,
-			false, false, false, false, false, false, false)
+			false, false, false, false, false, false, false, false)
 		if len(dirFiles(txPath)) != 0 || len(dirFiles(rxPath)) == 0 {
 			return false
 		}
 		ctx.Neigh[*nodeOur.Id].FreqPath = &spool
 		ctx.Toss(ctx.Self.Id, TRx, DefaultNiceFreq,
-			false, false, false, false, false, false, false)
+			false, false, false, false, false, false, false, false)
 		if len(dirFiles(txPath)) != 0 || len(dirFiles(rxPath)) == 0 {
 			return false
 		}
@@ -399,7 +399,7 @@ func TestTossFreq(t *testing.T) {
 			}
 		}
 		ctx.Toss(ctx.Self.Id, TRx, DefaultNiceFreq,
-			false, false, false, false, false, false, false)
+			false, false, false, false, false, false, false, false)
 		if len(dirFiles(txPath)) == 0 || len(dirFiles(rxPath)) != 0 {
 			return false
 		}
@@ -504,7 +504,7 @@ func TestTossTrns(t *testing.T) {
 			}
 		}
 		ctx.Toss(ctx.Self.Id, TRx, 123,
-			false, false, false, false, false, false, false)
+			false, false, false, false, false, false, false, false)
 		if len(dirFiles(rxPath)) != 0 {
 			return false
 		}
